function [A6, b6, ctype6] = MBKS_zostav_obmedzenie_typ6(n, m, z, pocet_neznamych_celkom, D)
% Funkcia pre zostavenie subcasti matice obmedzeni A, subcasti vektoru
% pravych stran b a subcasti vektoru znakov ctype pre sieste zavazne
% obmedzenie
% 
% Volanie
%   [A6, b6, ctype6] = MBKS_zostav_obmedzenie_typ6(n, m, z, pocet_neznamych_celkom, D)
% Vstup:
%   n - pocet sestier
%   m - pocet dni planovaneho obdobia
%   z - pocet smien
%   pocet_neznamych_celkom - celkovy pocet neznamych pre zavazne aj nezavazne poziadavky
%   D - min predpisany pocet sestier na smenach
% Výstup:
%   A6 - subcast matice obmedzeni A
%   b6 - subcast vektoru pravych stran b
%   ctype6 - subcast vektoru znakov ctype
%% ABOUT
% Funkcia MBKS_zostav_obmedzenie_typ6 si zavola vstupne premenne zo
% skriptu MBKS_vstupne_parametre. Jej vystupy budu predstavovat cast matice
% ombedzeni A, vektoru pravych stran b, a parametru ctype. 
%
% Na zaciatku si zadeklarujeme premenne pocet_obmedzeni a
% pocet_nenulovych_prvkov, potrebnych pre urcenie velkosti casti matice
% obmedzeni A6, casti vektoru pravych stran b6 a casti parametru ctype6
%
% Pomocou funkcie salloc sa allokuje A6 a nasledne pomocou sustavy
% vnorenych cyklov typu for sa bude A6 naplnat. Maticu A6 sa naplna
% postupnym prechadzanim kazdeho riadku cr a k nemu odpovedajucih stlpcov.
%
% Na zaver sa naplni cast vektoru pravych stran b6 a zvoli vhodna hodnota
% parametru ctype6

%% Deklarovanie parametrov
pocet_obmedzeni = m * z;
pocet_nenulovych_prvkov = n * pocet_obmedzeni;

%% Inicializacia casti matice obmedzeni A6
A6 = spalloc(pocet_obmedzeni, pocet_neznamych_celkom, pocet_nenulovych_prvkov);

%% Naplnenie casti matice obmedzeni A6
cr = 1; % Cislo 1. riadku matice
for j = 1:m
    for k = 1:z
        for i = 1:n
            A6(cr, i + (j - 1) * n + (k - 1) * m * n) = 1;
        end
        cr = cr + 1; % Posun na dalsi riadok matice 
    end
end

%% Naplnenie casti vektoru pravych stran b6 a casti parametru ctype6
DT=D'; % Transponovanie matice D
b6 = DT(:); % Transformacia matice D' do vektoru
ctype6(1:pocet_obmedzeni) = 'L'; % v obmedzeniach sa objavuju nerovnosti >=, preto hodnota L

end